@@ -31,10 +31,11 @@ class RetryInterrupt(_MrqInterrupt):
     delay = None
     queue = None
     retry_count = 0
+    path = None
 
     def _get_exception_name(self):
         return "%s #%s: %s seconds, %s queue" % (
-            self.__class__.__name__, self.retry_count, self.delay, self.queue
+            self.path, self.retry_count, self.delay, self.queue
         )
 
 
