@@ -237,10 +237,11 @@ class Job(object):
             max_retries = self.max_retries
 
         if self.data.get("retry_count", 0) >= max_retries:
-            raise MaxRetriesInterrupt()
+            raise MaxRetriesInterrupt(self.data.get("path"))
 
         exc = RetryInterrupt()
 
+        exc.path = self.data.get("path")
         exc.queue = queue or self.queue or self.data.get("queue") or "default"
         exc.retry_count = self.data.get("retry_count", 0) + 1
         exc.delay = delay
